from sensor.Sensor import Sensor
from utils.datatypes import *
from utils import i18n

import commands
import os
import time
import imaplib

class imapmail(Sensor):
	
	def __init__(self, interval = "60000"):
		self.__newmail = 0
		self.__msgcount = 0
		self.__boxsize = 0
		
		Sensor.__init__(self)
		
		self._set_config_type("update", TYPE_INT, int(interval))
		self._set_config_type("imap_server", TYPE_STRING, "")
		self._set_config_type("imap_login", TYPE_STRING, "")
		self._set_config_type("imap_password", TYPE_STRING, "")
		
		self._add_timer(int(interval), self.__on_tick)
		self._add_thread(self.__command_thread, 0.001 * int(interval))

	def get_configurator(self):

		configurator = self._new_configurator()
		configurator.set_name("IMAP mail check")
		configurator.add_title("Settings")
		configurator.add_spin("Update every (ms):", "update",
					"Updates the display(s) every x milliseconds",
					1*1000, 3600*24*1000)
		configurator.add_entry("Host", "imap_server",
					"Host (imap server)")
		configurator.add_entry("Login", "imap_login",
					"Login")
		configurator.add_entry("Password", "imap_password",
					"Password",passwd = 1)
		
		return configurator

	def __on_tick(self):

		data = self._new_output()
		data.set("newmail", self.__newmail)
		data.set("msgcount",self.__msgcount)
		if self.__boxsize != "Connection error":
			data.set("boxsize","%s total" % self.__boxsize)
		else :
			data.set("boxsize",self.__boxsize)
			
		if self.__boxsize=="Connection error":
			data.set("error",1)
		else :
			data.set("error",0)
			
		if self.__newmail==0 and self.__boxsize!="Connection error":
			data.set("nonewmail", 1)
		else :
			data.set("nonewmail", 0)
			
		data.set("host", self._get_config("imap_server"))
		data.set("login", self._get_config("imap_login"))
		self._send_output(data)

		return 1



	def __command_thread(self, interval):

		while (1):
			if (self._is_stopped()): break
			
			try :
				imap = imaplib.IMAP4(self._get_config("imap_server"))
				imap.login(self._get_config("imap_login"),self._get_config("imap_password"))
			
				imap.select("INBOX",readonly=1)
				imap.noop()
				unseen = imap.search(None, '(UNSEEN UNDELETED)')
				total = imap.search(None, '(UNDELETED)')
				
				#self.__msgcount,self.__boxsize = len(srch[0][1].split())
				self.__msgcount = len(unseen[1][0].split())
				self.__boxsize = len(total[1][0].split())

				imap.close()
				imap.logout()
				
			except :
				self.__msgcount = 666
				self.__boxsize = "Connection error"
			
			
			if self.__msgcount : 
				self.__newmail = 1
			else :
				self.__newmail = 0
			
			
			time.sleep(0.001*self._get_config("update"))
				


def new_sensor(args): return apply(imapmail, args)
